@@ -1,6 +1,6 @@
 from ._version import __version__
 from .backtesting import backtest
-from .connect import connect_sqlite
+from .connect import connect_postgres, connect_sqlite
 from .creator import SETSignalCreator
 from .reader import SETDataReader
 from .report import SETBacktestReport
