@@ -1,5 +1,5 @@
-MARKET_SET = INDEX_SET = "SET"
-MARKET_MAI = INDEX_MAI = "mai"
+MARKET_SET = "SET"
+MARKET_MAI = "mai"
 
 MARKET_MAP = {MARKET_SET: "A", MARKET_MAI: "S"}
 MARKET_MAP_UPPER = {k.upper(): v for k, v in MARKET_MAP.items()}
@@ -67,15 +67,6 @@ SECTOR_PROP = "PROP"
 SECTOR_STEEL = "STEEL"
 SECTOR_TOURISM = "TOURISM"
 SECTOR_TRANS = "TRANS"
-# MAI SECTOR
-SECTOR_AGRO = "AGRO"
-SECTOR_CONSUMP = "CONSUMP"
-SECTOR_FINCIAL = "FINCIAL"
-SECTOR_INDUS = "INDUS"
-SECTOR_PROPCON = "PROPCON"
-SECTOR_RESOURC = "RESOURC"
-SECTOR_SERVICE = "SERVICE"
-SECTOR_TECH = "TECH"
 
 SECTOR_LIST = [
     v for k, v in locals().items() if isinstance(k, str) and k.startswith("SECTOR_")
